@@ -3,6 +3,7 @@ from typing import Union
 from pydantic import validator
 from typing_extensions import Literal
 
+from ..structures.distinct import Distinct
 from ..functions.base import BaseFunction
 from ..properties import Array
 from ..properties.property import Property
@@ -11,7 +12,7 @@ from ..structures.cast_operator import CastOperator
 
 class StringAgg(BaseFunction):
     obj: Literal['functions.StringAgg'] = 'functions.StringAgg'
-    property: Union[Property, BaseFunction, Array, CastOperator]
+    property: Union[Property, BaseFunction, Array, CastOperator, Distinct]
     separator: str
     alias: str = None
 
